import Foundation

enum GameType: Codable {
    
    enum GameClass: Int {
        case ruf = 1
        case hochzeit = 2
        case bettel = 3
        case wenzGeier = 4
        case solo = 5
        
        var cost: Int {
            switch self {
            case .ruf: return 5
            case .hochzeit: return 10
            case .bettel: return 15
            case .wenzGeier, .solo: return 20
            }
        }
    }
    
    case rufEichel
    case rufBlatt
    case rufSchelln
    case hochzeit
    case bettel
    case wenz
    case geier
    case soloEichel
    case soloBlatt
    case soloHerz
    case soloSchelln
    
    var gameClass: GameClass {
        switch self {
        case .rufEichel, .rufBlatt, .rufSchelln:
            return .ruf
        case .hochzeit:
            return .hochzeit
        case .bettel:
            return .bettel
        case .wenz, .geier:
            return .wenzGeier
        case .soloEichel, .soloBlatt, .soloHerz, .soloSchelln:
            return .solo
        }
    }
    
    var isSingleGame: Bool {
        switch self {
        case .rufEichel, .rufBlatt, .rufSchelln, .hochzeit:
            return false
        default:
            return true
        }
    }
    
    var basicCost: Int {
        gameClass.cost
    }
    
    var sortingType: CardOrder.Type {
        switch self {
        case .wenz:
            return WenzCardOrder.self
        case .geier:
            return GeierCardOrder.self
        case .soloEichel:
            return SoloEichelCardOrder.self
        case .soloBlatt:
            return SoloBlattCardOrder.self
        case .soloSchelln:
            return SoloSchellnCardOrder.self
        default:
            return NormalCardOrder.self
        }
    }
}
